#
# spec file for package python-fastjsonschema
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-fastjsonschema
Version:        2.21.1
Release:        1.1
Summary:        Fastest Python implementation of JSON schema
License:        BSD-3-Clause
URL:            https://github.com/horejsek/python-fastjsonschema
Source:         https://files.pythonhosted.org/packages/source/f/fastjsonschema/fastjsonschema-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-json-spec
Suggests:       python-jsonschema
Suggests:       python-validictory
BuildArch:      noarch
%python_subpackages

%description
Fastest Python implementation of JSON schema

%prep
%autosetup -p1 -n fastjsonschema-%{version}

%build
%pyproject_wheel

%check
%pytest

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/fastjsonschema
%{python_sitelib}/fastjsonschema-%{version}.dist-info

%changelog
* Thu Dec  5 2024 Dirk Müller <dmueller@suse.com>
- update to 2.21.1:
  * Fixed ResourceWarning where file was not properly closed
  * Fixed regexp for date format
  * Updated test suite
  * Fixed detecting when infinity is reached with multipleOf
  * Fixed that min/max items/lenght/properties can be float
  * Fixed that everything with empty `not` is invalid
  * Fixed missing re import when using regex pattern
  * Improved regexp for email format to comfort test suite
  * Improved regexp for date format to comfort test suite
  * Improved regexp for ipv4 format to comfort test suite
  * Added partial support of idn-hostname format
  * Added `detailed_exceptions` flag (default to True to avoid
    breaking change) - when used, results are twice as fast
* Wed Nov 20 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 2.20.0:
  - Added validations at compile time:
  - `required` must have unique items
  - checking if schema is not allowing `required` items (item
    is required, but is not listed in properties)
- Remove upstreamed patch:
  - support-pytest-8.patch
* Tue May  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-pytest-8.patch:
  * Support pytest >= 8.
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.19.1:
  * Fixed date format to accept only two digit months and days
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.19.0:
  * Added `use_formats` parameter to allow disable automatic assertions
* Tue Sep 26 2023 Torsten Gruner <simmphonie@opensuse.org>
- update to 2.18.0
  * Improved error message for required props - only missing are reported
  * Fixed support of boolean schema in if-then-else application
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 2.17.1:
  * Fixed tests in sdist
  * Added support for Decimals
  * Added tests in sdist
* Fri May 12 2023 Daniel Garcia <daniel.garcia@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Mon Mar  6 2023 Dirk Müller <dmueller@suse.com>
- update to 2.16.3:
  * Fix variable name resolving with references
* Thu Oct  6 2022 Dirk Müller <dmueller@suse.com>
- update to 2.16.2:
  * Use temporary dir in tests for compiled code
  * Add comments to Python versions in Github workflow
  * Add conditional test that uses $ref
  * Add conditional tests just to make sure the baseline works
  * Recursively expand all $ref strings in schemas
  * Add test case capturing the desired behaviour
  * Expand $ref when assiging the definition field in JsonSchemaValueExce
  * Add an assertion before removing 'data' from variable name
* Mon Jul 18 2022 Matej Cepl <mcepl@suse.com>
- Cleanup the SPEC file.
* Sat Jul 16 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright
- update to version 2.15.3:
  * Fix swapping handlers
  * Fix tests
  * Readable regexps in generated code
- changes from version 2.15.2:
  * Fix nested oneOf and anyOf
  * Fix if-else block in anyOf block
  * Fix uniqueItems including lists or dicts
  * Add option to pass custom formats in generated code
- changes from version 2.15.1:
  * Fix parsing date-time with +hhmm format
  * Fix generating code with custom regular expressions
- changes from version 2.15.0:
  * Fix additional property equal to empty object is the same as True
  * Fix const with "
  * Add const to error message
  * Add JsonSchemaValueException (replacement for JsonSchemaException)
    + JsonSchemaException is base exception
    + JsonSchemaDefinitionException no longer inherits from
    JsonSchemaValueException
  * New option `use_default` to have option turn off default feature
    (`True` by default to be compatible)
- changes from version 2.14.5:
  * Fix missing dependencies
  * Fix schema cache
* Fri Jun 12 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.14.4
